==> smart_arrays_base-2.0.3.tar.gz: README.md <==
## Smart Arrays Base


### What the package can do for you
This package provides basic functionalities for one- and two-dimensional arrays (vectors and matrices). 


### The major API functionalities

- class `Array1D`: This class provides utility functions for 1D arrays (vectors):
    - adding arrays with various options
    - Finding the minimum or maximum values with various options
    - splitting, shuffling, swapping and extracting given index ranges
    - extending with zeroes, cutting
    - computing the integral function of an array
    
- class `Array2D`:This class provides utility functions for 2D arrays (matrices):
   - Extracting rows, columns, appending rows
   - Extracting sub-matrices, building envelopes
   - Computing projections or sums over rows or columns
   - Swapping or reversing rows
   - Finding minimum or maximum values
   - Integrating a submatrix
 

#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Using this package
You need Dart 2.0 or later.

Import the package using:
- `import 'package:smart_arrays_base/smart_arrays_base.dart';`

### Related packages


[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size.]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_arrays_peaks`: Detect peaks in 1D and 2D arrays.]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_lorentz-gauss`: Compute Lorentz-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

[`smart_signal_processing`: Fourier transform and more.]( https://pub.dartlang.org/packages/smart_signal_processing)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)

==> smart_arrays_base-2.0.4.tar.gz: README.md <==
## Smart Arrays Base


### What the package can do for you
This package provides basic functionalities for one- and two-dimensional arrays (vectors and matrices). 


### The major API functionalities

- class `Array1D`: This class provides utility functions for 1D arrays (vectors):
    - adding arrays with various options
    - Finding the minimum or maximum values with various options
    - splitting, shuffling, swapping and extracting given index ranges
    - extending with zeroes, cutting
    - computing the integral function of an array
    
- class `Array2D`:This class provides utility functions for 2D arrays (matrices):
   - Extracting rows, columns, appending rows
   - Extracting sub-matrices, building envelopes
   - Computing projections or sums over rows or columns
   - Swapping or reversing rows
   - Finding minimum or maximum values
   - Integrating a submatrix
 

#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Using this package
You need Dart 2.0 or later.

Import the package using:
- `import 'package:smart_arrays_base/smart_arrays_base.dart';`

### Related packages

[`smart_arrays_numerics`: Numerics with 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_numerics)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size.]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_arrays_peaks`: Detect peaks in 1D and 2D arrays.]( https://pub.dartlang.org/packages/smart_arrays_peaks)

[`smart_arrays_lmfit`: Fits (x, y) data given as arrays to a specified model function using the  Levenberg-Marquardt algorithm.]( https://pub.dartlang.org/packages/smart_arrays_lmfit)

[`smart_lorentz-gauss`: Compute Lorentz-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

[`smart_signal_processing`: Fourier transform and more.]( https://pub.dartlang.org/packages/smart_signal_processing)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)
